==> openshift-model-operatorhub-6.9.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/ComponentsFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ComponentsFluent<A extends ComponentsFluent<A>> extends BaseFluent<A>{
  public ComponentsFluent() {
  }
  
  public ComponentsFluent(Components instance) {
    this.copyInstance(instance);
  }
  private LabelSelectorBuilder labelSelector;
  private List<JsonNode> refs = new ArrayList<JsonNode>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Components instance) {
    instance = (instance != null ? instance : new Components());
  
    if (instance != null) {
        this.withLabelSelector(instance.getLabelSelector());
        this.withRefs(instance.getRefs());
        this.withLabelSelector(instance.getLabelSelector());
        this.withRefs(instance.getRefs());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public LabelSelector buildLabelSelector() {
    return this.labelSelector!=null ?this.labelSelector.build():null;
  }
  
  public A withLabelSelector(LabelSelector labelSelector) {
    _visitables.get("labelSelector").remove(this.labelSelector);
    if (labelSelector!=null){ this.labelSelector= new LabelSelectorBuilder(labelSelector); _visitables.get("labelSelector").add(this.labelSelector);} else { this.labelSelector = null; _visitables.get("labelSelector").remove(this.labelSelector); } return (A) this;
  }
  
  public boolean hasLabelSelector() {
    return this.labelSelector != null;
  }
  
  public LabelSelectorNested<A> withNewLabelSelector() {
    return new LabelSelectorNested(null);
  }
  
  public LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item) {
    return new LabelSelectorNested(item);
  }
  
  public LabelSelectorNested<A> editLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(null));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item) {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(item));
  }
  
  public A addToRefs(int index,JsonNode item) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    this.refs.add(index, item);
    return (A)this;
  }
  
  public A setToRefs(int index,JsonNode item) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    this.refs.set(index, item); return (A)this;
  }
  
  public A addToRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    for (JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  
  public A addAllToRefs(Collection<JsonNode> items) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    for (JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  
  public A removeFromRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    if (this.refs == null) return (A)this;
    for (JsonNode item : items) { this.refs.remove(item);} return (A)this;
  }
  
  public A removeAllFromRefs(Collection<JsonNode> items) {
    if (this.refs == null) return (A)this;
    for (JsonNode item : items) { this.refs.remove(item);} return (A)this;
  }
  
  public List<JsonNode> getRefs() {
    return this.refs;
  }
  
  public JsonNode getRef(int index) {
    return this.refs.get(index);
  }
  
  public JsonNode getFirstRef() {
    return this.refs.get(0);
  }
  
  public JsonNode getLastRef() {
    return this.refs.get(refs.size() - 1);
  }
  
  public JsonNode getMatchingRef(Predicate<JsonNode> predicate) {
    for (JsonNode item: refs) { if(predicate.test(item)){ return item;} } return null;
  }
  
  public boolean hasMatchingRef(Predicate<JsonNode> predicate) {
    for (JsonNode item: refs) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withRefs(List<JsonNode> refs) {
    if (refs != null) {this.refs = new ArrayList(); for (JsonNode item : refs){this.addToRefs(item);}} else { this.refs = null;} return (A) this;
  }
  
  public A withRefs(com.fasterxml.jackson.databind.JsonNode... refs) {
    if (this.refs != null) {this.refs.clear(); _visitables.remove("refs"); }
    if (refs != null) {for (JsonNode item :refs){ this.addToRefs(item);}} return (A) this;
  }
  
  public boolean hasRefs() {
    return refs != null && !refs.isEmpty();
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ComponentsFluent that = (ComponentsFluent) o;
    if (!java.util.Objects.equals(labelSelector, that.labelSelector)) return false;
  
    if (!java.util.Objects.equals(refs, that.refs)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(labelSelector,  refs,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (labelSelector != null) { sb.append("labelSelector:"); sb.append(labelSelector + ","); }
    if (refs != null && !refs.isEmpty()) { sb.append("refs:"); sb.append(refs + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class LabelSelectorNested<N> extends LabelSelectorFluent<LabelSelectorNested<N>> implements Nested<N>{
    LabelSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) ComponentsFluent.this.withLabelSelector(builder.build());
    }
    
    public N endLabelSelector() {
      return and();
    }
    
  
  }

}

==> openshift-model-operatorhub-6.9.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1/ComponentsFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.LabelSelector;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ComponentsFluent<A extends ComponentsFluent<A>> extends BaseFluent<A>{
  public ComponentsFluent() {
  }
  
  public ComponentsFluent(Components instance) {
    this.copyInstance(instance);
  }
  private LabelSelectorBuilder labelSelector;
  private List<JsonNode> refs = new ArrayList<JsonNode>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(Components instance) {
    instance = (instance != null ? instance : new Components());
    if (instance != null) {
          this.withLabelSelector(instance.getLabelSelector());
          this.withRefs(instance.getRefs());
          this.withLabelSelector(instance.getLabelSelector());
          this.withRefs(instance.getRefs());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public LabelSelector buildLabelSelector() {
    return this.labelSelector != null ? this.labelSelector.build() : null;
  }
  
  public A withLabelSelector(LabelSelector labelSelector) {
    this._visitables.remove(this.labelSelector);
    if (labelSelector != null) {
        this.labelSelector = new LabelSelectorBuilder(labelSelector);
        this._visitables.get("labelSelector").add(this.labelSelector);
    } else {
        this.labelSelector = null;
        this._visitables.get("labelSelector").remove(this.labelSelector);
    }
    return (A) this;
  }
  
  public boolean hasLabelSelector() {
    return this.labelSelector != null;
  }
  
  public LabelSelectorNested<A> withNewLabelSelector() {
    return new LabelSelectorNested(null);
  }
  
  public LabelSelectorNested<A> withNewLabelSelectorLike(LabelSelector item) {
    return new LabelSelectorNested(item);
  }
  
  public LabelSelectorNested<A> editLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(null));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelector() {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(new LabelSelectorBuilder().build()));
  }
  
  public LabelSelectorNested<A> editOrNewLabelSelectorLike(LabelSelector item) {
    return withNewLabelSelectorLike(java.util.Optional.ofNullable(buildLabelSelector()).orElse(item));
  }
  
  public A addToRefs(int index,JsonNode item) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    this.refs.add(index, item);
    return (A)this;
  }
  
  public A setToRefs(int index,JsonNode item) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    this.refs.set(index, item); return (A)this;
  }
  
  public A addToRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    for (JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  
  public A addAllToRefs(Collection<JsonNode> items) {
    if (this.refs == null) {this.refs = new ArrayList<JsonNode>();}
    for (JsonNode item : items) {this.refs.add(item);} return (A)this;
  }
  
  public A removeFromRefs(com.fasterxml.jackson.databind.JsonNode... items) {
    if (this.refs == null) return (A)this;
    for (JsonNode item : items) { this.refs.remove(item);} return (A)this;
  }
  
  public A removeAllFromRefs(Collection<JsonNode> items) {
    if (this.refs == null) return (A)this;
    for (JsonNode item : items) { this.refs.remove(item);} return (A)this;
  }
  
  public List<JsonNode> getRefs() {
    return this.refs;
  }
  
  public JsonNode getRef(int index) {
    return this.refs.get(index);
  }
  
  public JsonNode getFirstRef() {
    return this.refs.get(0);
  }
  
  public JsonNode getLastRef() {
    return this.refs.get(refs.size() - 1);
  }
  
  public JsonNode getMatchingRef(Predicate<JsonNode> predicate) {
      for (JsonNode item : refs) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingRef(Predicate<JsonNode> predicate) {
      for (JsonNode item : refs) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withRefs(List<JsonNode> refs) {
    if (refs != null) {
        this.refs = new ArrayList();
        for (JsonNode item : refs) {
          this.addToRefs(item);
        }
    } else {
      this.refs = null;
    }
    return (A) this;
  }
  
  public A withRefs(com.fasterxml.jackson.databind.JsonNode... refs) {
    if (this.refs != null) {this.refs.clear(); _visitables.remove("refs"); }
    if (refs != null) {for (JsonNode item :refs){ this.addToRefs(item);}} return (A) this;
  }
  
  public boolean hasRefs() {
    return this.refs != null && !this.refs.isEmpty();
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ComponentsFluent that = (ComponentsFluent) o;
    if (!java.util.Objects.equals(labelSelector, that.labelSelector)) return false;
    if (!java.util.Objects.equals(refs, that.refs)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(labelSelector,  refs,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (labelSelector != null) { sb.append("labelSelector:"); sb.append(labelSelector + ","); }
    if (refs != null && !refs.isEmpty()) { sb.append("refs:"); sb.append(refs + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class LabelSelectorNested<N> extends LabelSelectorFluent<LabelSelectorNested<N>> implements Nested<N>{
    LabelSelectorNested(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    LabelSelectorBuilder builder;
    
    public N and() {
      return (N) ComponentsFluent.this.withLabelSelector(builder.build());
    }
    
    public N endLabelSelector() {
      return and();
    }
    
  
  }

}
